package dpc

import (

)

type DpcGraphicMaterialTabApi struct {
}

// GetPage 获取图素表列表
// @Summary 获取图素表列表
// @Description 获取图素表列表
// @Tags 图素表
                 
// @Param pageSize query int false "页条数"
// @Param pageIndex query int false "页码"
// @Success 200 {object} response.Response{data=response.Page{list=[]models.DpcGraphicMaterialTab}} "{"code": 200, "data": [...]}"
// @Router /api/v1/dpc [get]
// @Security Bearer
func (api *DpcGraphicMaterialTabApi) GetPage(c *gin.Context) {
    req := dto.DpcGraphicMaterialTabGetPageReq{}
    s := service.DpcGraphicMaterialTab{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
   	if err != nil {
   		e.Logger.Error(err)
   		e.Error(500, err, err.Error())
   		return
   	}

	p := actions.GetPermissionFromContext(c)
	list := make([]models.DpcGraphicMaterialTab, 0)
	var count int64

	err = s.GetPage(&req, p, &list, &count)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("获取图素表失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.PageOK(list, int(count), req.GetPageIndex(), req.GetPageSize(), "查询成功")
}

// GetDpcGraphicMaterialTab 获取图素表
// @Summary 获取图素表
// @Description 获取图素表
// @Tags 图素表
// @Param id path int false "id"
// @Success 200 {object} response.Response{data=models.DpcGraphicMaterialTab} "{"code": 200, "data": [...]}"
// @Router /api/v1/dpc/{id} [get]
// @Security Bearer
func  (api *DpcGraphicMaterialTabApi) Get(c *gin.Context) {
	req := dto.DpcGraphicMaterialTabGetReq{}
	s := service.DpcGraphicMaterialTab{}
    err := e.MakeContext(c).
		MakeOrm().
		Bind(&req).
		MakeService(&s.Service).
		Errors
	if err != nil {
		e.Logger.Error(err)
		e.Error(500, err, err.Error())
		return
	}
	var object models.DpcGraphicMaterialTab

	p := actions.GetPermissionFromContext(c)
	err = s.Get(&req, p, &object)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("获取图素表失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.OK( object, "查询成功")
}

// saveDpcGraphicMaterialTab 创建图素表
// @Summary 创建图素表
// @Description 创建图素表
// @Tags 图素表
// @Accept application/json
// @Product application/json
// @Param data body dto.DpcGraphicMaterialTabInsertReq true "data"
// @Success 200 {object} response.Response	"{"code": 200, "message": "添加成功"}"
// @Router /api/v1/dpc [post]
// @Security Bearer
func  (api *DpcGraphicMaterialTabApi) Save(c *gin.Context) {
    req := dto.DpcGraphicMaterialTabInsertReq{}
    s := service.DpcGraphicMaterialTab{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }
	// 设置创建人
	req.SetCreateBy(user.GetUserId(c))

	err = s.Save(&req)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("创建图素表失败，\r\n失败信息 %s", err.Error()))
        return
	}

	e.OK(req.GetId(), "创建成功")
}

// UpdateDpcGraphicMaterialTab 修改图素表
// @Summary 修改图素表
// @Description 修改图素表
// @Tags 图素表
// @Accept application/json
// @Product application/json
// @Param id path int true "id"
// @Param data body dto.DpcGraphicMaterialTabUpdateReq true "body"
// @Success 200 {object} response.Response	"{"code": 200, "message": "修改成功"}"
// @Router /api/v1/dpc/{id} [put]
// @Security Bearer
func (api *DpcGraphicMaterialTabApi) Update(c *gin.Context) {
    req := dto.DpcGraphicMaterialTabUpdateReq{}
    s := service.DpcGraphicMaterialTab{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }
	req.SetUpdateBy(user.GetUserId(c))
	p := actions.GetPermissionFromContext(c)

	err = s.Update(&req, p)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("修改图素表失败，\r\n失败信息 %s", err.Error()))
        return
	}
	e.OK( req.GetId(), "修改成功")
}

// DelDpcGraphicMaterialTab 删除图素表
// @Summary 删除图素表
// @Description 删除图素表
// @Tags 图素表
// @Param data body dto.DpcGraphicMaterialTabDeleteReq true "body"
// @Success 200 {object} response.Response	"{"code": 200, "message": "删除成功"}"
// @Router /api/v1/dpc [delete]
// @Security Bearer
func (api *DpcGraphicMaterialTabApi) Delete(c *gin.Context) {
    s := service.DpcGraphicMaterialTab{}
    req := dto.DpcGraphicMaterialTabDeleteReq{}
    err := e.MakeContext(c).
        MakeOrm().
        Bind(&req).
        MakeService(&s.Service).
        Errors
    if err != nil {
        e.Logger.Error(err)
        e.Error(500, err, err.Error())
        return
    }

	// req.SetUpdateBy(user.GetUserId(c))
	p := actions.GetPermissionFromContext(c)

	err = s.Delete(&req, p)
	if err != nil {
		e.Error(500, err, fmt.Sprintf("删除图素表失败，\r\n失败信息 %s", err.Error()))
        return
	}
	e.OK( req.GetId(), "删除成功")
}
