package service

import (
	"errors"
)

type BindCustomerDataTabService struct {
}

// GetPage 获取BindCustomerDataTab列表
func (e *BindCustomerDataTabService) GetPage(c *dto.BindCustomerDataTabGetPageReq, p *actions.DataPermission, list *[]models.BindCustomerDataTab, count *int64) error {
	var err error
	var data models.BindCustomerDataTab

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("BindCustomerDataTabService GetPage error:%s \r\n", err)
		return err
	}
	return nil
}

// Get 获取BindCustomerDataTab对象
func (e *BindCustomerDataTabService) Get(d *dto.BindCustomerDataTabGetReq, p *actions.DataPermission, model *models.BindCustomerDataTab) error {
	var data models.BindCustomerDataTab

	err := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).
		First(model, d.GetId()).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetBindCustomerDataTab error:%s \r\n", err)
		return err
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err
	}
	return nil
}

// Insert 创建BindCustomerDataTab对象
func (e *BindCustomerDataTabService) Save(c *dto.BindCustomerDataTabInsertReq) error {
    var err error
    var data models.BindCustomerDataTab
    c.Generate(&data)
	err = e.Orm.Create(&data).Error
	if err != nil {
		e.Log.Errorf("BindCustomerDataTabService Insert error:%s \r\n", err)
		return err
	}
	return nil
}

// Update 修改BindCustomerDataTab对象
func (e *BindCustomerDataTabService) Update(c *dto.BindCustomerDataTabUpdateReq, p *actions.DataPermission) error {
    var err error
    var data = models.BindCustomerDataTab{}
    e.Orm.Scopes(
            actions.Permission(data.TableName(), p),
        ).First(&data, c.GetId())
    c.Generate(&data)

    db := e.Orm.Save(&data)
    if err = db.Error; err != nil {
        e.Log.Errorf("BindCustomerDataTabService Save error:%s \r\n", err)
        return err
    }
    if db.RowsAffected == 0 {
        return errors.New("无权更新该数据")
    }
    return nil
}

// Remove 删除BindCustomerDataTab
func (e *BindCustomerDataTabService) Delete(d *dto.BindCustomerDataTabDeleteReq, p *actions.DataPermission) error {
	var data models.BindCustomerDataTab

	db := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).Delete(&data, d.GetId())
	if err := db.Error; err != nil {
        e.Log.Errorf("Service RemoveBindCustomerDataTab error:%s \r\n", err)
        return err
    }
    if db.RowsAffected == 0 {
        return errors.New("无权删除该数据")
    }
	return nil
}
