package service

import (
	"errors"
)

type DpcGraphicMaterialTabService struct {
}

// GetPage 获取DpcGraphicMaterialTab列表
func (e *DpcGraphicMaterialTabService) GetPage(c *dto.DpcGraphicMaterialTabGetPageReq, p *actions.DataPermission, list *[]models.DpcGraphicMaterialTab, count *int64) error {
	var err error
	var data models.DpcGraphicMaterialTab

	err = e.Orm.Model(&data).
		Scopes(
			cDto.MakeCondition(c.GetNeedSearch()),
			cDto.Paginate(c.GetPageSize(), c.GetPageIndex()),
			actions.Permission(data.TableName(), p),
		).
		Find(list).Limit(-1).Offset(-1).
		Count(count).Error
	if err != nil {
		e.Log.Errorf("DpcGraphicMaterialTabService GetPage error:%s \r\n", err)
		return err
	}
	return nil
}

// Get 获取DpcGraphicMaterialTab对象
func (e *DpcGraphicMaterialTabService) Get(d *dto.DpcGraphicMaterialTabGetReq, p *actions.DataPermission, model *models.DpcGraphicMaterialTab) error {
	var data models.DpcGraphicMaterialTab

	err := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).
		First(model, d.GetId()).Error
	if err != nil && errors.Is(err, gorm.ErrRecordNotFound) {
		err = errors.New("查看对象不存在或无权查看")
		e.Log.Errorf("Service GetDpcGraphicMaterialTab error:%s \r\n", err)
		return err
	}
	if err != nil {
		e.Log.Errorf("db error:%s", err)
		return err
	}
	return nil
}

// Insert 创建DpcGraphicMaterialTab对象
func (e *DpcGraphicMaterialTabService) Save(c *dto.DpcGraphicMaterialTabInsertReq) error {
    var err error
    var data models.DpcGraphicMaterialTab
    c.Generate(&data)
	err = e.Orm.Create(&data).Error
	if err != nil {
		e.Log.Errorf("DpcGraphicMaterialTabService Insert error:%s \r\n", err)
		return err
	}
	return nil
}

// Update 修改DpcGraphicMaterialTab对象
func (e *DpcGraphicMaterialTabService) Update(c *dto.DpcGraphicMaterialTabUpdateReq, p *actions.DataPermission) error {
    var err error
    var data = models.DpcGraphicMaterialTab{}
    e.Orm.Scopes(
            actions.Permission(data.TableName(), p),
        ).First(&data, c.GetId())
    c.Generate(&data)

    db := e.Orm.Save(&data)
    if err = db.Error; err != nil {
        e.Log.Errorf("DpcGraphicMaterialTabService Save error:%s \r\n", err)
        return err
    }
    if db.RowsAffected == 0 {
        return errors.New("无权更新该数据")
    }
    return nil
}

// Remove 删除DpcGraphicMaterialTab
func (e *DpcGraphicMaterialTabService) Delete(d *dto.DpcGraphicMaterialTabDeleteReq, p *actions.DataPermission) error {
	var data models.DpcGraphicMaterialTab

	db := e.Orm.Model(&data).
		Scopes(
			actions.Permission(data.TableName(), p),
		).Delete(&data, d.GetId())
	if err := db.Error; err != nil {
        e.Log.Errorf("Service RemoveDpcGraphicMaterialTab error:%s \r\n", err)
        return err
    }
    if db.RowsAffected == 0 {
        return errors.New("无权删除该数据")
    }
	return nil
}
